:mod:`zope.testbrowser` API
===========================

:mod:`zope.testbrowser.interfaces`
----------------------------------

.. automodule:: zope.testbrowser.interfaces


Interfaces
~~~~~~~~~~

   .. autointerface:: ICookies
      :members:

   .. autointerface:: IBrowser
      :members:

   .. autointerface:: ILink
      :members:

   .. autointerface:: IForm
      :members:

   .. autointerface:: IControl
      :members:

   .. autointerface:: IListControl
      :members:

   .. autointerface:: ISubmitControl
      :members:

   .. autointerface:: IImageSubmitControl
      :members:

   .. autointerface:: IItemControl
      :members:

Exceptions
~~~~~~~~~~

  .. autoexception:: AlreadyExpiredError

  .. autoexception:: ExpiredError


:mod:`zope.testbrowser.browser`
-------------------------------

.. automodule:: zope.testbrowser.browser

Classes
~~~~~~~

    .. autoclass:: Browser
       :members:
